# Thanks to:

- Getting Things Gnome, whose wonderful panel icon I've appropriated
- Andrew from webupd8.org, for hosting `todo-indicator` in the webupd8 PPA
- Michael Mayer (@tenbaht), for his lovely python3 PR!
- Anyone who filed a bug!
